package com.coldlightalchemist.notesapp;

import static android.view.View.INVISIBLE;
import static android.view.View.VISIBLE;

import android.content.Intent;
import android.os.Bundle;
import android.util.Log;
import android.view.View;
import android.widget.TextView;

import androidx.activity.EdgeToEdge;
import androidx.appcompat.app.AppCompatActivity;
import androidx.core.graphics.Insets;
import androidx.core.view.ViewCompat;
import androidx.core.view.WindowInsetsCompat;
import androidx.recyclerview.widget.LinearLayoutManager;
import androidx.recyclerview.widget.RecyclerView;

import com.coldlightalchemist.notesapp.db.NoteDB;
import com.google.android.material.floatingactionbutton.FloatingActionButton;

public class MainActivity extends AppCompatActivity {
    private NoteDB db;

    private FloatingActionButton fab;

    private RecyclerView notesRecyclerView;

    private TextView noNotesText;

    private NotesRecyclerViewAdapter noteAdapter;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        EdgeToEdge.enable(this);
        setContentView(R.layout.activity_main);
        ViewCompat.setOnApplyWindowInsetsListener(findViewById(R.id.main), (v, insets) -> {
            Insets systemBars = insets.getInsets(WindowInsetsCompat.Type.systemBars());
            v.setPadding(systemBars.left, systemBars.top, systemBars.right, systemBars.bottom);
            return insets;
        });

        db = NoteDB.getDB(getApplicationContext());

        notesRecyclerView = (RecyclerView) findViewById(R.id.noteRecyclerView);
        notesRecyclerView.setLayoutManager(new LinearLayoutManager(this));

        noteAdapter = new NotesRecyclerViewAdapter(db.noteDAO(), this::startActivity);

        notesRecyclerView.setAdapter(noteAdapter);

        noNotesText = (TextView) findViewById(R.id.noNotesTextView);

        fab = (FloatingActionButton) findViewById(R.id.fab);
        fab.setOnClickListener((v) -> {
            Intent newNoteIntent = new Intent(v.getContext(), NewNote.class);
            startActivity(newNoteIntent);
        });

        if (db.noteDAO().getAll().isEmpty()) {
            noNotesText.setVisibility(VISIBLE);
            notesRecyclerView.setVisibility(View.GONE);
        } else {
            noNotesText.setVisibility(View.GONE);
            notesRecyclerView.setVisibility(VISIBLE);
        }
    }

    @Override
    protected void onResume() {
        super.onResume();

        notesRecyclerView.setAdapter(noteAdapter);
    }

    @Override
    protected void onDestroy() {
        super.onDestroy();
        db.close();
    }

}